@@ -3,7 +3,7 @@
 # @FileName : read_level_eval.py
 # @Software : NANOME project
 # @Organization : JAX Li Lab
-# @Website  : https://github.com/TheJacksonLaboratory/nanome
+# @Website  : https://github.com/LabShengLi/nanome
 
 """
 Read-level evaluation on methylation calls of tools, compute the performance results(F1, accuracy, ROC-AUC, etc.) in nanome paper.
@@ -586,7 +586,7 @@ if __name__ == '__main__':
 
     ## Set tmp dir for bedtools, each process use a bed tmp dir
     ## because the tmp dir files may be cleaned by the end of the process
-    bed_temp_dir = os.path.join(args.bedtools_tmp, dsname)
+    bed_temp_dir = os.path.join(args.bedtools_tmp, f"{dsname}_perf")
     os.makedirs(bed_temp_dir, exist_ok=True)
     pybedtools.helpers.set_tempdir(bed_temp_dir)
 
