@@ -3,7 +3,7 @@
 # @FileName : site_level_eval.py
 # @Software : NANOME project
 # @Organization : JAX Li Lab
-# @Website  : https://github.com/TheJacksonLaboratory/nanome
+# @Website  : https://github.com/LabShengLi/nanome
 
 """
 Generate site-level methylation correlation results in nanome paper.
@@ -451,7 +451,7 @@ if __name__ == '__main__':
     dsname = args.dsname
     ## Set tmp dir for bedtools, each process use a bed tmp dir
     ## because the tmp dir files may be cleaned by the end of the process
-    bed_temp_dir = os.path.join(args.bedtools_tmp, dsname)
+    bed_temp_dir = os.path.join(args.bedtools_tmp, f"{dsname}_corr")
     os.makedirs(bed_temp_dir, exist_ok=True)
     pybedtools.helpers.set_tempdir(bed_temp_dir)
 
